nengo\_spa\.vocabulary
======================

.. automodule:: nengo_spa.vocabulary

   .. rubric:: Classes

   .. autosummary::

      Vocabulary
      VocabularyMap
      VocabularyMapParam
      VocabularyOrDimParam
